Prerequisites
-------------
PyQt4 installed into system python, on Linux, Windows or OSX.

In virtualenv
-------------

Make sure pip and setuptools are up to date

(my-virtualenv) $ pip install -U pip setuptools

Allow virtualenv to access PyQt4

(my-virtualenv) $ pip install vext.pyqt4


Reporting Bugs
--------------

Report bugs to the [vext project](//github.com/stuaxo/vext/issues)


This is *Experimental* I haven't used PyQt4 much, feedback, patches welcome :)
